/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_surface_h__
#define __glass_surface_h__

typedef struct _GlassSurface GlassSurface;

#include "global.h"
#include "glass_triangle.h"

/* A list of triangles, that are grouped together */
struct _GlassSurface
{
  char *name;

  int index, alpha_index;
  int visible;

  GlassTriangle *triangles, *alpha_triangles, *last_triangle, *last_alpha;
  GlassSurface *next;
};

/* Returns an empty surface */
GlassSurface *_glassSurfaceNew(const char *name);

/* Set the name of the surface */
void _glassSurfaceSetName(GlassSurface *surface, const char *name);

/* Get the name of the surface */
const char *_glassSurfaceGetName(GlassSurface *surface);

/* Try to make an openGL display list for the triangles, and one for the alpha triangles */
void _glassSurfaceMakeDisplayLists(GlassSurface *surface);

/* Set the visiblility of the surface */
void _glassSurfaceSetVisibility(GlassSurface *surface, int visible);

/* Free a surface, and the triangles it uses */
void _glassFreeSurfaceChild(GlassSurface *surface);

#endif /* __glass_surface_h__ */
