/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_transform_h__
#define __glass_transform_h__

/* The types of transforms */
enum _GlassTransformType
{
  GLASS_NONE = 0,
  GLASS_TRANSLATE,
  GLASS_ROTATE,
  GLASS_SCALE,
  GLASS_TRANSLATE_X,
  GLASS_TRANSLATE_Y,
  GLASS_TRANSLATE_Z,
  GLASS_ROTATE_X,
  GLASS_ROTATE_Y,
  GLASS_ROTATE_Z,
  GLASS_SCALE_X,
  GLASS_SCALE_Y,
  GLASS_SCALE_Z,
  GLASS_SCALE_EVEN
};
typedef enum _GlassTransformType GlassTransformType;
typedef struct _GlassTransform GlassTransform;

#include "global.h"
#include "glass_variable.h"

/* An openGL transform */
struct _GlassTransform
{
  GlassTransformType type;
  GlassVariable **variables;
  GLfloat **values;
};

/* Returns a new transform */
GlassTransform *_glassTransformNew(GlassTransformType type);

/* Get the number of parameters used by a transform */
int _glassTransformGetnParams(GlassTransformType type);

/* Set the type of the transform, resizing arrays as necessary */
void _glassTransformSetType(GlassTransform *transform, GlassTransformType type);

/* Get the type of the transform */
GlassTransformType _glassTransformGetType(GlassTransform *transform);

/* Set one of the parameters to a constant */
/* `param' is the parameter for the transform (starting from 0) */
void _glassTransformSetConstant(GlassTransform *transform, int param, GLfloat value);

/* Set one of the parameters to a variable */
/* `param' is the parameter for the transform (starting from 0) */
void _glassTransformSetVariable(GlassTransform *transform, int param, GlassVariable *variable);

/* Free a transform */
void _glassFreeTransform(GlassTransform *transform);

#endif /* __glass_transform_h__ */
